@@ -11,7 +11,7 @@ class ObjectIdentifier(x509.ObjectIdentifier):
     """A wrapped Object Identifier with custom factory methods."""
 
     @staticmethod
-    def is_dotted_string(oid: str) -> bool:
+    def _is_dotted_string(oid: str) -> bool:
         """Evaluate if a string is a dotted string."""
         if isinstance(oid, str) and re.fullmatch("^([0-9]+[.])*[0-9]+$", oid):
             return True
@@ -19,7 +19,7 @@ class ObjectIdentifier(x509.ObjectIdentifier):
         return False
 
     @staticmethod
-    def reverse_lookup(known_name: str) -> typing.Optional[str]:
+    def _reverse_lookup(known_name: str) -> typing.Optional[str]:
         """Lookup dotted string from a known ObjectIdentifier name."""
         for oid, name in _OID_NAMES.items():
             if known_name == name:
@@ -30,14 +30,16 @@ class ObjectIdentifier(x509.ObjectIdentifier):
     @classmethod
     def from_string(cls, oid: str):
         """
-        Create an ObjectIdentifier.
-
         Create an ObjectIdentifier from a dotted string or associated name.
+
+        :param str oid: String representation of an Object Identifier.
+        :return: The x509 representation of an Object Identifier.
+        :rtype: :class:`cryptography.x509.ObjectIdentifier`
         """
-        if cls.is_dotted_string(oid):
+        if cls._is_dotted_string(oid):
             return cls(oid)
 
-        dotted_string = cls.reverse_lookup(oid)
+        dotted_string = cls._reverse_lookup(oid)
 
         if dotted_string:
             return cls(dotted_string)
